@@ -1,6 +1,6 @@
 from typing import Optional, List, Dict
 from omymodels.pydantic import templates as pt
-from omymodels.utils import create_class_name, type_not_found, enum_number_name_list
+from omymodels.utils import create_class_name, enum_number_name_list
 from omymodels.pydantic.types import types_mapping, datetime_types
 
 
@@ -15,24 +15,25 @@ class ModelGenerator:
         self.custom_types = {}
         self.uuid_import = False
 
+    def add_custom_type(self, _type):
+        column_type = self.custom_types.get(_type, _type)
+        if isinstance(column_type, tuple):
+            _type = column_type[1]
+            column_type = column_type[0]
+        return _type
+
     def generate_attr(self, column: Dict, defaults_off: bool) -> str:
         if column["nullable"]:
             self.typing_imports.add("Optional")
             column_str = pt.pydantic_optional_attr
         else:
             column_str = pt.pydantic_attr
-
         if "." in column["type"]:
             _type = column["type"].split(".")[1]
         else:
             _type = column["type"].lower().split("[")[0]
         if self.custom_types:
-            column_type = self.custom_types.get(_type, _type)
-            if isinstance(column_type, tuple):
-                _type = column_type[1]
-                column_type = column_type[0]
-            if column_type != type_not_found:
-                column_type = f"{column_type}({_type})"
+            _type = self.add_custom_type(_type)
         if _type == _type:
             _type = types_mapping.get(_type, _type)
         if _type in self.types_for_import:
@@ -46,15 +47,21 @@ class ModelGenerator:
             self.uuid_import = True
 
         column_str = column_str.format(arg_name=column["name"], type=_type)
-        if column["default"] and defaults_off is False:
-            if column["type"].upper() in datetime_types:
-                if "now" in column["default"]:
-                    # todo: need to add other popular PostgreSQL & MySQL functions
-                    column["default"] = "datetime.datetime.now()"
-                elif "'" not in column["default"]:
-                    column["default"] = f"'{column['default']}'"
-            column_str += pt.pydantic_default_attr.format(default=column["default"])
 
+        if column["default"] and defaults_off is False:
+            column_str = self.add_default_values(column_str, column)
+
+        return column_str
+
+    @staticmethod
+    def add_default_values(column_str: str, column: Dict) -> str:
+        if column["type"].upper() in datetime_types:
+            if "now" in column["default"]:
+                # todo: need to add other popular PostgreSQL & MySQL functions
+                column["default"] = "datetime.datetime.now()"
+            elif "'" not in column["default"]:
+                column["default"] = f"'{column['default']}'"
+        column_str += pt.pydantic_default_attr.format(default=column["default"])
         return column_str
 
     def generate_model(
@@ -87,7 +94,9 @@ class ModelGenerator:
     def create_header(self, *args, **kwargs) -> str:
         header = ""
         if self.enum_imports:
-            header += pt.enum_import.format(enums=",".join(self.enum_imports)) + "\n"
+            self.enum_imports = list(self.enum_imports)
+            self.enum_imports.sort()
+            header += pt.enum_import.format(enums=", ".join(self.enum_imports)) + "\n"
         if self.uuid_import:
             header += pt.uuid_import + "\n"
         if self.datetime_import:
@@ -98,13 +107,13 @@ class ModelGenerator:
             header += pt.typing_imports.format(typing_types=", ".join(_imports)) + "\n"
         self.imports = list(self.imports)
         self.imports.sort()
-        header += pt.pydantic_imports.format(imports=", ".join(self.imports)) + "\n"
+        header += pt.pydantic_imports.format(imports=", ".join(self.imports))
         return header
 
     def generate_type(
         self, _type: Dict, singular: bool = False, exceptions: Optional[List] = None
     ) -> str:
-        """ method to prepare one Model defention - name & tablename  & columns """
+        """ method to prepare one Model defention - name & tablename & columns """
         type_class = ""
         if _type["properties"].get("values"):
             # mean this is a Enum
