@@ -3,17 +3,13 @@ postgresql_dialect_import = "from sqlalchemy.dialects.postgresql import {types}"
 sql_alchemy_func_import = "from sqlalchemy.sql import func"
 index_import = "from sqlalchemy import Index"
 
-sqlalchemy_import = """import sqlalchemy as sa
-from sqlalchemy import Table, Column, MetaData
-"""
-sqlalchemy_init = "metadata = MetaData()"
 unique_cons_import = "from sqlalchemy.schema import UniqueConstraint"
 enum_import = "from enum import {enums}"
 
 # model defenition
 table_template = """\n
 {table_var} = Table("{table_name}", metadata,
-{columns}{schema}{constraints})
+{columns}{constraints}{schema})
 """
 
 # columns defenition
@@ -31,7 +27,7 @@ fk_constraint_template = """
         [{fk_columns}], [{fk_references_columns}])
 """
 fk_in_column = ", sa.ForeignKey('{ref_table}.{ref_column}')"
-unique_index_template = """\nUniqueConstraint({columns}, name={name})"""
+unique_index_template = """        UniqueConstraint({columns}, name={name}),\n"""
 
 index_template = """\nIndex({name}, {columns})"""
 
